/**
* Copyright (c) 2019 Razeware LLC
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*/

import Cocoa

class ViewController: NSViewController {

	@IBOutlet weak var pastTenseVerbTextField: NSTextField!
	@IBOutlet weak var singularNounCombo: NSComboBox!
	@IBOutlet weak var pluralNounPopup: NSPopUpButton!
	@IBOutlet var phraseTextView: NSTextView!
	
	fileprivate let singularNouns = ["dog", "muppet", "ninja", "pirate", "dev" ]
	fileprivate let pluralNouns = ["tacos", "rainbows", "iPhones", "gold coins"]
	fileprivate enum VoiceRate: Int  {
		case slow
		case normal
		case fast

		var speed: Float {
			switch self {
			case .slow:
				return 60
			case .normal:
				return 175;
			case .fast:
				return 360;
			}
		}
	}
	fileprivate let synth = NSSpeechSynthesizer()

	override func viewDidLoad() {
		super.viewDidLoad()

		// Sets the default text for the pastTenseVerbTextField property
		pastTenseVerbTextField.stringValue = "ate"

		// Setup the combo box with singular nouns
		singularNounCombo.removeAllItems()
		singularNounCombo.addItems(withObjectValues: singularNouns)
		singularNounCombo.selectItem(at: singularNouns.count-1)

		// Setup the pop up button with plural nouns
		pluralNounPopup.removeAllItems()
		pluralNounPopup.addItems(withTitles: pluralNouns)
		pluralNounPopup.selectItem(at: 0)

		// Setup the default text to display in the text view
		phraseTextView.string = "Me coding Mac Apps!!!"
	}

	override var representedObject: Any? {
		didSet {
		// Update the view, if already loaded.
		}
	}

	@IBAction func goButtonClicked(_ sender: Any) {
		let pastTenseVerb = pastTenseVerbTextField.stringValue
		let singularNoun = singularNounCombo.stringValue
		let pluralNoun = pluralNouns[pluralNounPopup.indexOfSelectedItem]
		let phrase = phraseTextView.string

		let madLibSentence = "A \(singularNoun) \(pastTenseVerb) \(pluralNoun) and said, \(phrase)!"
		readSentence(madLibSentence, rate: .normal)

		//print("\(madLibSentence)")
	}

	fileprivate func readSentence(_ sentence: String, rate: VoiceRate ) {
		synth.rate = rate.speed
		synth.stopSpeaking()
		synth.startSpeaking(sentence)
	}

}
